@@ -109,7 +109,6 @@ Atom::Atom (int Z, double x, double y, double z):
 	m_ChargeAuto = false;
 	m_HPos = GetBestSide ();
 	m_nlp = m_nlu = 0;
-	SetZ(Z);
 	m_ascent = 0;
 	m_CHeight = 0.;
 	m_Changed = 0;
@@ -124,6 +123,7 @@ Atom::Atom (int Z, double x, double y, double z):
 	m_SWidth = 0.;
 	m_ChargeItem = NULL;
 	m_ShowCharge = true;
+	SetZ(Z);
 }
 
 Atom::Atom (OBAtom* atom):
@@ -136,7 +136,6 @@ Atom::Atom (OBAtom* atom):
 	m_y = - atom->GetY ();
 	m_z = atom->GetZ ();
 	m_nlp = m_nlu = 0;
-	SetZ (atom->GetAtomicNum ());
 	gchar* Id = g_strdup_printf ("a%d", atom->GetIdx());
 	SetId (Id);
 	g_free (Id);
@@ -156,6 +155,7 @@ Atom::Atom (OBAtom* atom):
 	m_SWidth = 0.;
 	m_ChargeItem = NULL;
 	m_ShowCharge = true;
+	SetZ (atom->GetAtomicNum ());
 }
 
 void Atom::SetZ (int Z)
@@ -210,7 +210,7 @@ int Atom::GetTotalBondsNumber () const
 void Atom::AddBond (gcu::Bond* pBond)
 {
 	gcu::Atom::AddBond (pBond);
-	Update ();
+	m_Changed = true;
 }
 
 void Atom::RemoveBond (gcu::Bond* pBond)
@@ -300,9 +300,6 @@ void Atom::Update ()
 			m_ChargeAuto = true;
 		}
 	}
-	Document *pDoc = (Document *) GetDocument ();
-	if (pDoc && pDoc->GetView ())
-		m_Changed = pDoc->GetView ()->GetNbWidgets ();
 	m_AvailPosCached = false;
 	map<gcu::Atom*, gcu::Bond*>::iterator j = m_Bonds.begin(), jend = m_Bonds.end ();
 	if (nbonds && GetZ () == 6) {
@@ -335,10 +332,8 @@ void Atom::Update ()
 					DrawCircle = true;
 			}
 		}
-		if (DrawCircle != m_DrawCircle) {
+		if (DrawCircle != m_DrawCircle)
 			m_DrawCircle = DrawCircle;
-			m_Changed = true;
-		}
 	}
 	// Update all double bonds
 	for (j = m_Bonds.begin(); j != jend; j++)
@@ -1086,6 +1081,25 @@ void Atom::SetCharge (int charge)
 	Update ();
 }
 
+void Atom::Move (double x, double y, double z)
+{
+	gcu::Atom::Move (x, y, z);
+	map<string, Object*>::iterator i;
+	Object* electron = GetFirstChild (i);
+	while (electron) {
+		electron->Move (x, y, z);
+		electron = GetNextChild (i);
+	}
+	if (GetCharge ()) {
+		if (m_ChargeAutoPos) {
+			if (m_ChargePos > 0)
+				NotifyPositionOccupation (m_ChargePos, false);
+			m_ChargePos = 0xff;
+			Update ();
+		}
+	}
+}
+
 void Atom::Transform2D (Matrix2D& m, double x, double y)
 {
 	gcu::Atom::Transform2D (m, x, y);
@@ -1305,8 +1319,12 @@ void Atom::BuildSymbolGeometry (double width, double height, double ascent)
 
 void Atom::AddItem ()
 {
-	if (m_Item)
+	if (m_Item || GetZ() <= 0)
 		return;
+	if (m_Changed) {
+		Update ();
+		m_Changed = false;
+	}
 	Document *doc = static_cast <Document*> (GetDocument ());
 	View *view = doc->GetView ();
 	Theme *theme = doc->GetTheme ();
