@@ -4,7 +4,7 @@
  * GChemPaint library
  * atom.h 
  *
- * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -202,6 +202,16 @@ that they give the absolute position.
 @param x the x position.
 @param y the y position.
 
+Updates \a x and \a y so that they become the position corresponding to the angle
+when the position is available, the origin being the position of the atom.
+@return true on success, false otherwise.
+*/
+	virtual bool GetRelativePosition (double angle, double& x, double& y);
+/*!
+@param angle the angle at which a charge sign or an electron should be displayed.
+@param x the x position.
+@param y the y position.
+
 Updates \a x and \a y so that they become the absolute position corresponding to the angle
 when the position is available.
 @return true on success, false otherwise.
@@ -256,6 +266,14 @@ the maximum valence for the element.
 */
 	virtual double GetYAlign ();
 /*!
+@param x the x component of the transation vector.
+@param y the y component of the transation vector.
+@param z the z component of the transation vector.
+
+Used to move an Atom.
+*/
+	virtual void Move (double x, double y, double z = 0.);
+/*!
 @param m the Matrix2D of the transformation.
 @param x the x component of the center of the transformation.
 @param y the y component of the center of the transformation.
@@ -361,8 +379,19 @@ This method is used to avoid bonds lines extyending over their atoms symbols.
 */
 	void GetSymbolGeometry (double &width, double &height, double &angle, bool up) const;
 
+/*!
+@param paired whether to ask for a pair of electrons or a single electron.
+@return true if non-bonding valence electrons are available.
+*/
 	bool HasAvailableElectrons (bool paired);
 
+/*!
+@param angle the angle from the east direction in the trigonometric convention.
+
+@return the bond at or near the direction given by \a angle.
+*/
+	Bond *GetBondAtAngle (double angle);
+
 protected:
 /*!
 @param width the witdh of the atomic symbol.
@@ -440,8 +469,30 @@ Sets the position of attached hydrogen atoms symbol.
 @return the position of attached hydrogen atoms symbol as a reference.
 */
 GCU_PROP (HPos, HPosStyle) //0=force left, 1=force right, 2=force top, 3=force bottom, 4=auto.
-GCU_PROP (gccv::Item *, ChargeItem) //0=force left, 1=force right, 2=force top, 3=force bottom, 4=auto.
+/*!\fn SetChargeItem(gccv::Item *item)
+@param item a gccv::Item.
 
+Sets the gccv::Item used to represent the formal charge of the atom, might be NULL.
+*/
+/*!\fn GetChargeItem()
+@return the gccv::Item used to represent the formal charge of the atom.
+*/
+/*!\fn GetChargeItem() const
+@return the gccv::Item used to represent the formal charge of the atom.
+*/
+GCU_POINTER_PROP (gccv::Item, ChargeItem)
+/*!\fn SetShowCharge(bool show)
+@param show whether to display the local charge.
+
+Shows or hides the atom local charge.
+*/
+/*!\fn GetShowCharge()
+@return whether the local charge is displayed.
+*/
+/*!\fn GetShowCharge()
+@return whether the local charge is displayed as a reference.
+*/
+GCU_PROP (bool, ShowCharge);
 };
 
 }	//	namespace gcp
