@@ -4,7 +4,7 @@
  * GChemPaint library
  * document.cc 
  *
- * Copyright (C) 2001-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2001-2008 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -547,7 +547,7 @@ void Document::AddBond (Bond* pBond)
 	if (pBond->GetParent () == NULL)
 		AddChild (pBond);
 	Atom *pAtom0 = (Atom*) pBond->GetAtom (0), *pAtom1 = (Atom*) pBond->GetAtom (1);
-	if (m_pView->GetCanvas ()) {
+	if (m_pView->GetCanvas () && pAtom0 && pAtom1) {
 		pAtom0->UpdateItem ();
 		pAtom1->UpdateItem ();
 		pBond->AddItem ();
@@ -563,11 +563,7 @@ void Document::AddBond (Bond* pBond)
 			m_pView->Update (pBond);
 		} else {
 			//merge two molecules
-			if (pMol1->GetParent () != this) {
-				pMol1->Merge (pMol0);
-				pMol0 = pMol1;
-			} else
-				pMol0->Merge (pMol1);
+			pMol0->Merge (pMol1);
 		}
 		pMol0->AddBond (pBond);
 	}
@@ -878,7 +874,8 @@ xmlDocPtr Document::BuildXMLTree () const
 
 void Document::Update ()
 {
-	std::set<Object*>::iterator i,  end = m_DirtyObjects.end ();
+	std::set <Object *>::iterator i,  end = m_DirtyObjects.end ();
+	std::set <Object *> Deleted;
 	TypeId Id;
 	for (i = m_DirtyObjects.begin (); i != end; i++) {
 		Id = (*i)->GetType ();
@@ -886,8 +883,17 @@ void Document::Update ()
 		case gcu::BondType:
 			m_pView->Update ((Bond*) (*i));
 			break;
+		case gcu::MoleculeType:
+			if ((*i)->GetChildrenNumber() == 0)
+					Deleted.insert (*i);
+			break;
+		default:
+			break;
 		}
 	}
+	end = Deleted.end ();
+	for (i = Deleted.begin (); i != end; i++)
+		delete *i;
 	m_DirtyObjects.clear ();
 }
 	
@@ -992,8 +998,6 @@ void Document::RemoveBond (Bond* pBond)
 		if ((pAtom1->GetZ () == 6) && (pAtom1->GetBondsNumber () == 0))
 			m_pView->Update (pAtom1);
 		Parent->Lock (false);
-		if (!m_bUndoRedo && !m_bIsLoading && dynamic_cast <ModifyOperation *> (m_pCurOp))
-			m_pCurOp->AddObject (pMol, 1);
 	}
 	m_DirtyObjects.erase (pBond);
 	delete pBond;
@@ -1087,7 +1091,6 @@ void Document::AddObject (Object* pObject)
 	if (m_bIsLoading || m_bUndoRedo)
 		return;
 	if (!m_pCurOp) {
-		// FIXME: this is a bit dangerous and should be removed in the future
 		m_pCurOp = new AddOperation (this, ++m_OpID);
 		m_pCurOp->AddObject (pObject);
 	}
@@ -1097,6 +1100,7 @@ void Document::OnUndo ()
 {
 	if (m_pApp->GetActiveTool ()->OnUndo ())
 		return;
+	m_pView->GetData ()->UnselectAll ();
 	m_bUndoRedo = true;
 	if (!m_UndoList.empty ()) {
 		Operation* Op = m_UndoList.front ();
@@ -1112,6 +1116,7 @@ void Document::OnUndo ()
 		m_Window->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", HasChildren ());
 	}
 	m_bUndoRedo = false;
+	Loaded ();
 	Update ();
 	EmptyTranslationTable ();
 	SetDirty (m_LastStackSize != m_UndoList.size () || (m_LastStackSize > 0 && m_OpID != m_UndoList.front ()->GetID ()));
@@ -1122,6 +1127,7 @@ void Document::OnRedo ()
 {
 	if (m_pApp->GetActiveTool ()->OnRedo ())
 		return;
+	m_pView->GetData ()->UnselectAll ();
 	m_bUndoRedo = true;
 	if (!m_RedoList.empty ()) {
 		Operation* Op = m_RedoList.front ();
@@ -1137,6 +1143,7 @@ void Document::OnRedo ()
 		m_Window->ActivateActionWidget ("/MainMenu/FileMenu/SaveAsImage", HasChildren ());
 	}
 	m_bUndoRedo = false;
+	Loaded ();
 	EmptyTranslationTable ();
 	SetDirty (m_LastStackSize != m_UndoList.size () || (m_LastStackSize > 0 && m_OpID != m_UndoList.front ()->GetID ()));
 	m_Empty = !HasChildren ();
@@ -1234,26 +1241,27 @@ void Document::LoadObjects (xmlNodePtr node)
 			m_bIsLoading = true;
 			child1 = (strcmp ((const char*) child->name, "object"))? child: child->children;
 			str = (const char*) child1->name;
-			Object* pObject = Object::CreateObject (str, this);
+			Object* pObject = GetApp ()->CreateObject (str, this);
 			pObject->Load (child1);
 			AddObject (pObject);
-			m_pView->Update (pObject);//FIXME: should not be necessary, but solve problem with cyclic double bonds
 			m_bIsLoading = false;
 		}
 		child = child->next;
 	}
 	//Now, add bonds
+	m_bIsLoading = true;
 	child = GetNodeByName (node, "bond");
 	while (child) {
 		Bond* pBond = new Bond ();
 		AddChild (pBond);
 		if (pBond->Load (child))
 			AddBond (pBond);
-		else delete pBond;
+		else
+			delete pBond;
 		child = GetNextNodeByName (child->next, "bond");
 	}
+	m_bIsLoading = false;
 	Loaded ();
-	// FIXME: we might just update what needs update, not the whole document
 	m_pView->Update (this);
 }
 
@@ -1272,7 +1280,7 @@ Operation* Document::GetNewOperation (OperationType type)
 	}
 }
 
-void Document::AddData (xmlNodePtr node)
+void Document::PasteData (xmlNodePtr node)
 {
 	xmlNodePtr child;
 	string str;
@@ -1281,10 +1289,15 @@ void Document::AddData (xmlNodePtr node)
 	EmptyTranslationTable ();
 	GtkWidget* w = m_pView->GetWidget ();
 	WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (w), "data");
+	gcu::Application *app = GetApp ();
+	if (!app)
+		app = Application::GetApplication ("GChemPaint");
+	if (!app)
+		return; // TODO: may be an exception there
 	while (node) {
 		child = (strcmp ((const char*) node->name, "object"))? node: node->children;
 		str = (const char*) child->name;
-		pObject = Object::CreateObject (str, this);
+		pObject = app->CreateObject (str, this);
 		AddObject (pObject);
 		if (!pObject->Load (child))
 			Remove (pObject);
@@ -1295,8 +1308,8 @@ void Document::AddData (xmlNodePtr node)
 		node = node->next;
 	}
 	m_bIsLoading = false;
-	EmptyTranslationTable ();
 	Loaded ();
+	EmptyTranslationTable ();
 	FinishOperation ();
 }
 
@@ -1329,7 +1342,7 @@ double Document::GetYAlign ()
 		WidgetData* pData = (WidgetData*) g_object_get_data (G_OBJECT (GetWidget ()), "data");
 		gccv::Rect rect;
 		pData->GetObjectBounds (this, &rect);
-		return (rect.y1 - rect.y0) / 2. / m_Theme->GetZoomFactor ();
+		return (rect.y1 - rect.y0) / 2.;
 	}
 }
 
