@@ -465,11 +465,6 @@ void Fragment::AddItem ()
 		m_Atom->SetChargeItem (text);
 	} else
 		m_Atom->SetChargeItem (NULL);
-	// update the size
-	gccv::Rect rect;
-	m_TextItem->GetBounds (&rect, NULL);
-	m_length = rect.x1 - rect.x0;
-	m_height = rect.y1 - rect.y0;
 }
 
 void Fragment::UpdateItem ()
@@ -522,9 +517,11 @@ void Fragment::UpdateItem ()
 void Fragment::SetSelected (int state)
 {
 	GOColor color, othercolor = 0;
+	bool visible = true;
 	switch (state) {	
 	case SelStateUnselected:
 		color = GO_COLOR_BLACK;
+		visible = false;
 		break;
 	case SelStateSelected:
 		color = SelectColor;
@@ -686,7 +683,6 @@ bool Fragment::Load (xmlNodePtr node)
 	char* tmp;
 	double size = (double) pTheme->GetFontSize () / PANGO_SCALE;
 	gccv::TextTag *tag;
-	m_Atom->SetId ("a0"); // avoids confusion with another atom while loading
 	while (child) {
 		if (!strcmp ((const char*) child->name, "text")) {
 			tmp = (char*) xmlNodeGetContent (child);
@@ -694,13 +690,13 @@ bool Fragment::Load (xmlNodePtr node)
 				m_buf += tmp;
 			xmlFree (tmp);
 		} else if (!strcmp ((const char*) child->name, "atom")) {
-			AddChild (m_Atom);
 			if (!m_Atom->Load (child))
 				return false;
 			m_BeginAtom = m_buf.length ();
 			m_buf += m_Atom->GetSymbol();
 			m_Atom->SetCoords (m_x, m_y);
 			m_EndAtom = m_buf.length ();
+			AddChild (m_Atom);
 		} else if (!strcmp ((const char*) child->name, "residue")) {
 			// replace the atom by a residue
 			map<gcu::Atom*, gcu::Bond*>::iterator i;
@@ -820,6 +816,7 @@ bool Fragment::Load (xmlNodePtr node)
 		m_TextItem->RebuildAttributes ();
 	}
 	m_bLoading = false;
+	pDoc->ObjectLoaded (this);
 	return true;
 }
 
@@ -1074,6 +1071,8 @@ Object* Fragment::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 		return NULL;
 	if (m_Atom->GetBondsNumber () || m_Atom->GetCharge ())
 		return m_Atom;
+	if (!pDoc)
+		return NULL;
 	double x0, y0;
 	x0 = (x - m_x) * pTheme->GetZoomFactor () + m_lbearing;
 	y0 = (y - m_y) * pTheme->GetZoomFactor () + m_ascent;
@@ -1082,8 +1081,6 @@ Object* Fragment::GetAtomAt (double x, double y, G_GNUC_UNUSED double z)
 	unsigned index, trailing;
 	int cur;
 	index = m_TextItem->GetIndexAt (x0, y0);
-	if (index > 0)
-		index--;
 	char c = m_buf[index];
 	cur = index;
 	while ((c >= 'a') && (c <= 'z') && cur >= 0) {
@@ -1362,7 +1359,7 @@ bool Fragment::Validate ()
 			}
 			unsigned length = (*it)->GetEndIndex () - (*it)->GetStartIndex () - (err - charge);
 			if ((*err == '+' && length == 1) ||
-			    (!strncmp (err, "−", strlen ("−")) && length == strlen ("−")))
+			    (!strcmp (err, "−") && length == strlen ("−")))
 				continue;
 			// if we are there, we have an error
 			Document *pDoc = dynamic_cast<Document*> (GetDocument ());
@@ -1553,4 +1550,15 @@ std::string Fragment::Name ()
 	return _("Fragment");
 }
 
+bool Fragment::GetCoords (double *x, double *y, double *z) const
+{
+	if (x == NULL || y == NULL)
+		return false;
+	*x = m_x;
+	*y = m_y;
+	if (z)
+		*z = 0.;
+	return true;
+}
+
 }	//	namespace gcp
