@@ -4,7 +4,7 @@
  * GChemPaint library
  * reaction-operator.h 
  *
- * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -80,16 +80,23 @@ as left side and vertically as base line.
 /*!
 @param x where to store the x coordinate of the operator.
 @param y where to store the y coordinate of the operator.
+@param z where to store the z coordinate of the operator or NULL for 2D representations.
 
 Retrieves the current coordinates of the operator.
+@return true if successful and false if an error occurs (if x or y is NULL).
 */
-	bool GetCoords (double* x, double* y) const;
+	bool GetCoords (double* x, double* y, double *z = NULL) const;
 /*!
 Used to retrieve the y coordinate for alignment. 
 @return y coordinate used for reaction operators alignment.
 */
 	virtual double GetYAlign ();
 
+/*!
+@return the localized object generic name.
+*/
+	std::string Name ();
+
 private:
 	double m_x, m_y;
 	PangoLayout *m_Layout;
