@@ -348,7 +348,7 @@ bool SaveStruct::Save (xmlDocPtr xml, xmlNodePtr node, unsigned &index, string c
 		double rise = static_cast <gccv::RiseTextTag *> (m_tag)->GetRise ();
 		if (rise != 0) {
 			child = xmlNewDocNode (xml, NULL, reinterpret_cast <xmlChar const *> ((rise > 0)? "sup": "sub"), NULL);
-			char *buf = g_strdup_printf ("%g", fabs (rise) / PANGO_SCALE);
+			char *buf = g_strdup_printf ("%g", fabs (rise));
 			xmlNewProp (child, reinterpret_cast <xmlChar const *> ("height"), reinterpret_cast <xmlChar const *> (buf));
 			g_free (buf);
 			xmlAddChild (node, child);
@@ -579,6 +579,7 @@ bool Text::Load (xmlNodePtr node)
 		text->SetInterline (m_Interline);
 	}
 	m_bLoading = false;
+	GetDocument ()->ObjectLoaded (this);
 	return true;
 }
 
@@ -720,7 +721,7 @@ bool Text::LoadNode (xmlNodePtr node, unsigned &pos, int cur_size)
 	} else if (!strcmp ((const char*) node->name, "sub")) {
 		buf = (char*) xmlGetProp (node, (xmlChar*) "height");
 		if (buf) {
-			int rise = -strtod (buf, NULL) * PANGO_SCALE;
+			int rise = -strtoul (buf, NULL, 10) * PANGO_SCALE;
 			xmlFree (buf);
 			tag = new gccv::RiseTextTag (rise);
 		} else {
@@ -741,7 +742,7 @@ bool Text::LoadNode (xmlNodePtr node, unsigned &pos, int cur_size)
 	} else if (!strcmp ((const char*) node->name, "sup")) {
 		buf = (char*) xmlGetProp (node, (xmlChar*) "height");
 		if (buf) {
-			int rise = strtod (buf, NULL) * PANGO_SCALE;
+			int rise = strtoul (buf, NULL, 10) * PANGO_SCALE;
 			xmlFree (buf);
 			tag = new gccv::RiseTextTag (rise);
 		} else {
@@ -1013,4 +1014,18 @@ std::string Text::Name ()
 	return _("Text");
 }
 
+bool Text::GetCoords (double* x, double* y, double *z) const
+{
+	if (x == NULL || y == NULL || !m_Item)
+		return false;
+	double x1, y1;
+	Theme *theme = static_cast <Document*> (GetDocument ())->GetTheme ();
+	m_Item->GetBounds (*x, *y, x1, y1);
+	*x = (*x + x1) / 2. / theme->GetZoomFactor ();
+	*y = (*y + y1) / 2. / theme->GetZoomFactor ();
+	if (z)
+		*z = 0.;
+	return true;
+}
+
 }	//	namespace gcp
