@@ -4,7 +4,7 @@
  * GChemPaint library
  * text.h 
  *
- * Copyright (C) 2002-2009 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -169,12 +169,33 @@ and GCU_PROP_TEXT_JUSTIFICATION.
 */
 	bool SetProperty (unsigned property, char const *value);
 /*!
+@param interline the spacing.
+
+Sets the Text interline spacing expressed as points.
 */
 	void InterlineChanged (double interline);
 /*!
+@param justification a GtkJustification.
+
+Sets the justification for the Text. Only meaningful for multiline text.
 */
 	void JustificationChanged (GtkJustification justification);
 
+/*!
+@return the localized object generic name.
+*/
+	std::string Name ();
+
+	/*!
+@param x where to store the x coordinate of the center of the text.
+@param y where to store the y coordinate of the center of the text.
+@param z where to store the z coordinate of the center of the text or NULL.
+
+Retrieves the current coordinates of the operator. Aways set \a z to 0.
+@return true if successful and false if an error occurs (if x or y is NULL).
+*/
+	bool GetCoords (double* x, double* y, double *z = NULL) const;
+
 /*!\fn SetAnchor(gccv::Anchor Anchor)
 @param Anchor the new gccv::Anchor for the text.
 
