@@ -174,6 +174,8 @@ void View::OnDestroy (GtkWidget* widget)
 
 void View::Update (Object *pObject)
 {
+	if (!m_pWidget)
+		return;
 	gccv::ItemClient *client = dynamic_cast <gccv::ItemClient *> (pObject);
 	if (client)
 		client->UpdateItem ();
@@ -323,7 +325,7 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 	switch (*DataType) {
 	case GCP_CLIPBOARD_NATIVE:
 		xml = xmlParseMemory (data, length);
-		m_pDoc->AddData (xml->children->children);
+		m_pDoc->PasteData (xml->children->children);
 		xmlFreeDoc (xml);
 		break;
 	case GCP_CLIPBOARD_UTF8_STRING: {
@@ -374,6 +376,7 @@ void View::OnReceive (GtkClipboard* clipboard, GtkSelectionData* selection_data)
 		dx = m_lastx - (rect.x0 + rect.x1) / 2.;
 		dy = m_lasty - (rect.y0 + rect.y1) / 2.;
 	}
+	m_pData->SimplifySelection ();
 	m_pData->MoveSelection (dx, dy);
 	Tool *pTool = pApp->GetTool ("Select");
 	if (pTool)
