@@ -734,7 +734,7 @@ bool Window::VerifySaved ()
 	GtkWidget* mbox;
 	do {
 		gchar* str = g_strdup_printf (_("\"%s\" has been modified.  Do you wish to save it?"), m_Document->GetTitle ());
-		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, "%s", str);
+		mbox = gtk_message_dialog_new (NULL, GTK_DIALOG_MODAL, GTK_MESSAGE_QUESTION, GTK_BUTTONS_YES_NO, str);
 		g_free (str);
 		gtk_dialog_add_button (GTK_DIALOG (mbox),  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 		res = gtk_dialog_run (GTK_DIALOG (mbox));
@@ -746,7 +746,7 @@ bool Window::VerifySaved ()
 	} while ((res == GTK_RESPONSE_YES) && (m_Document->GetFileName () == NULL));
 	if (res == GTK_RESPONSE_NO)
 		m_Document->SetDirty (false);
-	return (res == GTK_RESPONSE_YES || res == GTK_RESPONSE_NO);
+	return (res != GTK_RESPONSE_CANCEL);
 }
 
 void Window::OnPageSetup ()
