@@ -42,12 +42,19 @@ class Dialog;
 class Molecule;
 class Residue;
 
+typedef enum {
+	ActionException,
+	ActionDelete,
+	ActionIgnore
+} Action;		
+
 class PendingTarget
 {
 public:
 	Object *parent;
 	Object *owner;
 	Object **target;
+	Action action;
 };
 
 /*!\class Document gcu/document.h
@@ -55,6 +62,7 @@ This class is the base document class.
 */
 class Document: public Object, virtual public DialogOwner
 {
+friend class Application;
 friend class Object;
 friend class Dialog;
 public:
@@ -155,21 +163,25 @@ it to return a consistent value. Default implementation returns NULL.
 @param owner the owner of the reference to the search object.
 
 Search the descendant of \a parent, or of the whole document if \a parent is not set
-whose Id is \id. I not found, the parameters are stored for post loading processing
+whose Id is \a id. I not found, the parameters are stored for post loading processing
 using gcu::Document::Loaded(), and \a target is set to NULL.
 if \a owner is not NULL, post processing will call its OnLoaded() method.
 @return true if the target object was found.
 */
-	bool SetTarget (char const *id, Object **target, Object *parent, Object *owner = NULL) throw (std::runtime_error);
+	bool SetTarget (char const *id, Object **target, Object *parent, Object *owner = NULL, Action action = ActionException) throw (std::runtime_error);
 
 /*!
 Processes pending references resulting from failed calls to SetTarget().
 @return true if any reference was set.
 */
 	virtual bool Loaded () throw (LoaderError);
-
+/*!
+@return the localized object generic name.
+*/
 	std::string Name ();
 
+	void ObjectLoaded (Object *obj);
+
 private:
 
 /*!
@@ -181,11 +193,12 @@ maintains a table to update links using Ids as identifiers. If Cache is set to t
 the table.
 GetNewId returns the translated id
 */
-	gchar* GetNewId (gchar* id, bool Cache = true);
+	char* GetNewId (char const *id, bool Cache = true);
 
 private:
 	std::map <std::string, std::string> m_TranslationTable;//used when Ids translations are necessary (on pasting...)
 	std::map <std::string, std::list <PendingTarget> > m_PendingTable;//used to set pointers to objects when loading does not occur in the ideal order
+	std::set<Object*> m_NewObjects;
 
 protected:
 /*!
