@@ -4,7 +4,7 @@
  * Gnome Chemistry Utils
  * object.h 
  *
- * Copyright (C) 2002-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -42,6 +42,9 @@
 namespace gcu
 {
 
+class Dialog;
+class Application;
+
 /*!\enum GcuTypeId
 This enumeration is used to determine the type of an Object instance.
 Possible values are:
@@ -104,6 +107,23 @@ The type of callbacks for adding new items to the contextual menu of an object.
 */
 typedef bool (*BuildMenuCb) (Object *target, GtkUIManager *UIManager, Object *object, double x, double y);
 
+class TypeDesc
+{
+public:
+	TypeDesc ();
+
+	TypeId Id;
+	Object* (*Create) ();
+	std::set <TypeId> PossibleChildren;
+	std::set <TypeId> PossibleParents;
+	std::set <TypeId> RequiredChildren;
+	std::set <TypeId> RequiredParents;
+	std::string CreationLabel;
+	std::list <BuildMenuCb> MenuCbs;
+};
+
+class Object;
+
 /*!\enum RuleId
 This enumeration is used to maintain a set of rules about the possible
 hierarchical of the document. They are used with two class names or ids.
@@ -137,6 +157,7 @@ This is the base class for most other objects in the gcu namespace.
 */
 class Object
 {
+friend class Application;
 public:
 /*!
 Used to create an object of type Id. Should only be called from the constructor of a derived class.
@@ -161,7 +182,7 @@ the Object::AddType method.
 /*!
 	@return the Id of the Object instance.
 */
-	gchar const *GetId () const {return m_Id;}
+	char const *GetId () const {return m_Id;}
 /*!
 	@param object the Object instance to add as a child.
 	
@@ -199,6 +220,12 @@ the Object::AddType method.
 	the Objects tree (only one should be found) or NULL if none is found.
 */
 	Document* GetDocument () const;
+/*!
+	Used to get the Application owning the Object. 
+	
+	@return the Application owning the Object or NULL.
+*/
+	Application* GetApplication () const;
 /*!
 @param Id the type of the ancestor searched.
 
@@ -277,6 +304,15 @@ Example: \code
 */
 	virtual bool Load (xmlNodePtr node);
 /*!
+@param x a pointer to the double value which will receive the x coordinate of the Object.
+@param y a pointer to the double value which will receive the y coordinate of the Object.
+@param z a pointer to the double value which will receive the z coordinate of the Object or NULL for 2D representations.
+
+Retrieves the coordinates of this Object if relevant.
+@return true if successful and false if an error occurs (if x or y is NULL).
+*/
+	virtual bool GetCoords (double *x, double *y, double *z = NULL) const;
+/*!
 @param x the x component of the transation vector.
 @param y the y component of the transation vector.
 @param z the z component of the transation vector.
@@ -454,6 +490,13 @@ Use this method to iterate through the list of Object instances linked to the ob
 */
 	Object* GetNextLink (std::set<Object*>::iterator& i);
 
+/*!
+@param object the object to link.
+
+Adds a link to \a object.
+*/
+	void Link (Object *object);
+
 /*!
 @param object the object to unlink.
 
@@ -464,7 +507,7 @@ Unlinks object and calls Object::OnUnlink.
 /*!
 @param object the object just unlinked by Object::Unlink.
 
-Virtual method called when an object hs been unlinked. Programs should not call it
+Virtual method called when an object has been unlinked. Programs should not call it
 directly, but should call Object::OnUnlink instead.
 */
 	virtual void OnUnlink (Object *object);
@@ -511,6 +554,38 @@ Deletes all children. Derived classes might override this method if needed.
 */
 	virtual void Clear ();
 
+/*!
+@return the object generic name.
+*/
+	virtual std::string Name ();
+
+/*!
+@return the object identity composed of the object name as returned by
+gcu::Object::Name() concatenated with its unique Id as returned by gcu::Object::GetId().
+*/
+	std::string Identity ();
+
+/*!
+@return the name of the properties dialog for this object if one exists, or NULL.
+*/
+	virtual char const *HasPropertiesDialog () const;
+
+/*!
+@return true if the object can be safely selected. Default implementation returns true.
+*/
+	virtual bool CanSelect () const {return true;}
+
+/*!
+Called by Object::Destructor() when the parent becomes empty. Default implementation does
+nothing.
+*/
+	virtual void NotifyEmpty () {;}
+
+/*!
+Exposes the gcu::Dialog related to the object properties if it exists.
+*/
+	void ShowPropertiesDialog ();
+
 /*!
 @param TypeName the name of the new type.
 @param CreateFunc a pointer to a function returning a pointer to a new object of the new type.
@@ -518,10 +593,21 @@ Deletes all children. Derived classes might override this method if needed.
 can be omitted.
 
 This method is used to register a new type derived from Object.
+
+This method is deprecated, use Application::AddType() instead.
+
 @return the Id of the new type.
 */
 	static TypeId AddType (std::string TypeName, Object* (*CreateFunc) (), TypeId id = OtherType);
 
+/*!
+@param id the Id of an existing type.
+@param TypeName a new name for the type.
+
+This method is used to add an alternative name to an existing type.
+*/
+	static void AddAlias (TypeId id, std::string TypeName);
+
 /*!
 @param TypeName the name of the new type.
 @param parent the parent of the newly created object or NULL. if NULL, the parameter can be omitted.
@@ -530,6 +616,8 @@ Used to create an object of type name TypeName. The Object::AddType method must
 TypeName parameter. if parent is given and not NULL, the new Object will be a child of parent.
 It will also be given a default Id.
 
+This method is deprecated, use Application::CreateObject() instead.
+
 @return a pointer to the newly created Object or NULL if the Object could not be created.
 */
 	static Object* CreateObject (const std::string& TypeName, Object* parent = NULL);
@@ -553,6 +641,8 @@ It will also be given a default Id.
 @param cb the BuildMenuCb callback to call when building the menu.
 
 adds a callback for modifying the contextual menu of objects of type Id.
+
+This method is deprecated, use Application::AddMenuCallback() instead.
 */
 	static void AddMenuCallback (TypeId Id, BuildMenuCb cb);
 
@@ -561,6 +651,8 @@ adds a callback for modifying the contextual menu of objects of type Id.
 @param rule the new rule value
 @param type2 the TypeId of the second class in the rule
 
+This method is deprecated, use Application::AddRule() instead.
+
 Adds a rule.
 */
 	static void AddRule (TypeId type1, RuleId rule, TypeId type2);
@@ -570,6 +662,8 @@ Adds a rule.
 @param rule the new rule value
 @param type2 the name of the second class in the rule
 
+This method is deprecated, use Application::AddRule() instead.
+
 Adds a rule.
 */
 	static void AddRule (const std::string& type1, RuleId rule, const std::string& type2);
@@ -578,6 +672,8 @@ Adds a rule.
 @param type the TypeId of a class
 @param rule a RuleId value
 
+This method is deprecated, use Application::GetRules() instead.
+
 @return the set of rules correponding to the RuleId value for this class.
 */
 	static  const std::set<TypeId>& GetRules (TypeId type, RuleId rule);
@@ -586,6 +682,8 @@ Adds a rule.
 @param type the name of a class
 @param rule a RuleId value
 
+This method is deprecated, use Application::GetRules() instead.
+
 @return the set of rules correponding to the RuleId value for this class.
 */
 	static const std::set<TypeId>& GetRules (const std::string& type, RuleId rule);
@@ -596,12 +694,16 @@ Adds a rule.
 
 Used to give a label for contextual menus used when the creation of an instance of
 the class seems possible.
+
+This method is deprecated, use Application::SetCreationLabel() instead.
 */
 	static void SetCreationLabel (TypeId Id, std::string Label);
 
 /*!
 @param Id the TypeId of a class
 
+This method is deprecated, use Application::GetCreationLabel() instead.
+
 @return the string defined by SetCreationLabel.
 */
 	static const std::string& GetCreationLabel (TypeId Id);
@@ -609,6 +711,8 @@ the class seems possible.
 /*!
 @param TypeName the name of a class
 
+This method is deprecated, use Application::GetCreationLabel() instead.
+
 @return the string defined by SetCreationLabel.
 */
 	static const std::string& GetCreationLabel (const std::string& TypeName);
@@ -618,15 +722,22 @@ the class seems possible.
 */
 	static SignalId CreateNewSignalId ();
 
+protected:
+/*!
+@return the gcu::Dialog related to the object properties or NULL if none exists.
+*/
+	virtual Dialog *BuildPropertiesDialog ();
+
 private:
 	Object* RealGetDescendant (const gchar* Id) const;
 
 private:
-	gchar* m_Id;
+	char* m_Id;
 	TypeId m_Type;
 	Object *m_Parent;
 	std::map<std::string, Object*> m_Children; //string is Id of object, so each object must have an Id
 	std::set<Object*> m_Links; //objects linked to this but outside of the hierarchy
+	TypeDesc const *m_TypeDesc;
 
 private:
 /*!
