@@ -35,6 +35,7 @@
 #include <gcu/residue.h>
 
 #include <goffice/app/module-plugin-defs.h>
+#include <gsf/gsf-output-memory.h>
 #include <glib/gi18n-lib.h>
 #include <openbabel/chemdrawcdx.h>
 #include <map>
@@ -53,6 +54,8 @@ using namespace gcu;
 #if G_BYTE_ORDER == G_LITTLE_ENDIAN
 #define READINT16(input,i) gsf_input_read (input, 2, (guint8*) &i)
 #define READINT32(input,i) gsf_input_read (input, 4, (guint8*) &i)
+#define WRITEINT16(output,i) gsf_output_write  (output, 2, (guint8*) &i)
+#define WRITEINT32(output,i) gsf_output_write  (output, 4, (guint8*) &i)
 #else
 unsigned char buffer[4];
 bool readint_res;
@@ -62,6 +65,14 @@ bool readint_res;
 #define READINT32(input,i) \
 	readint_res = gsf_input_read (input, 4, (guint8*) buffer), \
 	i = buffer[0] + (buffer[1] << 8) + (buffer[2] << 16) + (buffer[3] << 24), readint_res
+#define WRITEINT16(output,i) \
+	gsf_output_write  (output, 1, (guint8*) (&i) + 1);\
+	gsf_output_write  (output, 1, (guint8*) &i)
+#define WRITEINT32(output,i) \
+	gsf_output_write  (output, 1, (guint8*) (&i) + 3);\
+	gsf_output_write  (output, 1, (guint8*) (&i) + 2);\
+	gsf_output_write  (output, 1, (guint8*) (&i) + 1);\
+	gsf_output_write  (output, 1, (guint8*) &i)
 #endif
 
 typedef struct {
@@ -113,8 +124,8 @@ public:
 	CDXLoader ();
 	virtual ~CDXLoader ();
 
-	ContentType Read (Document *doc, GsfInput *in, char const *mime_type, IOContext *io);
-	bool Write (Object *obj, GsfOutput *out, char const *mime_type, IOContext *io, ContentType type);
+	ContentType Read (Document *doc, GsfInput *in, char const *mime_type, GOIOContext *io);
+	bool Write (Object *obj, GsfOutput *out, char const *mime_type, GOIOContext *io, ContentType type);
 
 private:
 	bool ReadGenericObject (GsfInput *in);
@@ -129,12 +140,27 @@ private:
 	guint16 ReadSize (GsfInput *in);
 	bool ReadDate (GsfInput *in);
 
+	bool WriteObject (GsfOutput *out, Object *object, GOIOContext *io);
+	static void AddInt16Property (GsfOutput *out, gint16 prop, gint16 value);
+	static void AddInt32Property (GsfOutput *out, gint16 prop, gint32 value);
+	static void WriteSimpleStringProperty (GsfOutput *out, gint16 id, gint16 length, char const *data);
+	static bool WriteAtom (CDXLoader *loader, GsfOutput *out, Object *obj, GOIOContext *s);
+	static bool WriteBond (CDXLoader *loader, GsfOutput *out, Object *obj, GOIOContext *s);
+	static bool WriteMolecule (CDXLoader *loader, GsfOutput *out, Object *obj, GOIOContext *s);
+	void WriteId (Object *obj, GsfOutput *out);
+
 private:
 	char *buf;
 	size_t bufsize;
-	map<unsigned, CDXFont> fonts;
+	map<unsigned, CDXFont> m_Fonts;
 	vector <string> colors;
 	guint8 m_TextAlign, m_TextJustify;
+
+	map <string, bool (*) (CDXLoader *, GsfOutput *, Object *, GOIOContext *)> m_WriteCallbacks;
+	map<unsigned, GOColor> m_Colors;
+	map <string, gint32> m_SavedIds;
+	gint32 m_MaxId;
+	unsigned m_Z;
 };
 
 CDXLoader::CDXLoader ():
@@ -142,6 +168,10 @@ CDXLoader::CDXLoader ():
 	m_TextJustify (0)
 {
 	AddMimeType ("chemical/x-cdx");
+	// Add write callbacks
+	m_WriteCallbacks["atom"] = WriteAtom;
+	m_WriteCallbacks["bond"] = WriteBond;
+	m_WriteCallbacks["molecule"] = WriteMolecule;
 }
 
 CDXLoader::~CDXLoader ()
@@ -149,7 +179,7 @@ CDXLoader::~CDXLoader ()
 	RemoveMimeType ("chemical/x-cdx");
 }
 
-ContentType CDXLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED IOContext *io)
+ContentType CDXLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io)
 {
 	if (doc == NULL || in == NULL)
 		return ContentTypeUnknown;
@@ -166,6 +196,9 @@ ContentType CDXLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 		code = 0;
 	}
 
+	// set a default scale
+	doc->SetProperty (GCU_PROP_THEME_BOND_LENGTH, "1966080");
+
 	while (code) {
 		if (code & kCDXTag_Object) {
 			switch (code) {
@@ -241,7 +274,7 @@ ContentType CDXLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 					gsf_input_read (in, size, (guint8*) buf);
 					buf[size] = 0;
 					font.name = buf;
-					fonts[font.index] = font;
+					m_Fonts[font.index] = font;
 				}
 			}
 			break;
@@ -271,7 +304,7 @@ ContentType CDXLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 						result = ContentTypeUnknown;
 			}
 		}
-		if (!result != ContentType2D)
+		if (result != ContentType2D)
 			break;
 		if (!(READINT16 (in,code))) {
 			result = ContentTypeUnknown;
@@ -279,20 +312,257 @@ ContentType CDXLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 		}
 	}
 	delete [] buf;
-	fonts.clear ();
+	m_Fonts.clear ();
 	return result;
 }
 
-bool CDXLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED G_GNUC_UNUSED char const *mime_type, IOContext *io, G_GNUC_UNUSED ContentType type)
+/******************************************************************************
+ *	Write callbacks															  *
+ ******************************************************************************/
+ 
+bool CDXLoader::WriteAtom (CDXLoader *loader, GsfOutput *out, Object *obj, G_GNUC_UNUSED GOIOContext *s)
 {
+	gint16 n = kCDXObj_Node;
+	double x, y;
+	gint32 x_, y_;
+	WRITEINT16 (out, n);
+	loader->WriteId (obj, out);
+	string prop = obj->GetProperty (GCU_PROP_POS2D);
+	if (prop.length ()) {
+		sscanf (prop.c_str (), "%lg %lg", &x, &y);
+		x_ = x;
+		y_ = y;
+		n = kCDXProp_2DPosition;
+		WRITEINT16 (out, n);
+		gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x08\x00"));
+		// write y first
+		WRITEINT32 (out, y_);
+		WRITEINT32 (out, x_);
+	}
+	AddInt16Property (out, kCDXProp_ZOrder, loader->m_Z++);	
+	prop = obj->GetProperty (GCU_PROP_ATOM_Z);
+	if (prop != "6") {
+		n = kCDXProp_Node_Element;
+		WRITEINT16 (out, n);
+		gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x02\x00"));
+		n = strtol (prop.c_str (), NULL, 10);
+		WRITEINT16 (out, n);
+	}
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x00\x00")); // end of atom
+	return true;
+}
+
+bool CDXLoader::WriteBond (CDXLoader *loader, GsfOutput *out, Object *obj, G_GNUC_UNUSED GOIOContext *s)
+{
+	gint16 n = kCDXObj_Bond;
+	WRITEINT16 (out, n);
+	loader->WriteId (obj, out);
+	AddInt16Property (out, kCDXProp_ZOrder, loader->m_Z++);	
+	string prop = obj->GetProperty (GCU_PROP_BOND_BEGIN);
+	AddInt32Property (out, kCDXProp_Bond_Begin, loader->m_SavedIds[prop]);
+	prop = obj->GetProperty (GCU_PROP_BOND_END);
+	AddInt32Property (out, kCDXProp_Bond_End, loader->m_SavedIds[prop]);
+	prop = obj->GetProperty (GCU_PROP_BOND_ORDER);
+	if (prop == "3")
+		AddInt16Property (out, kCDXProp_Bond_Order, 4);	
+	else if (prop == "2")
+		AddInt16Property (out, kCDXProp_Bond_Order, 2);	
+	prop = obj->GetProperty (GCU_PROP_BOND_TYPE);
+	if (prop == "wedge")
+		AddInt16Property (out, kCDXProp_Bond_Display, 6);	
+	else if (prop == "hash")
+		AddInt16Property (out, kCDXProp_Bond_Display, 3);	
+	else if (prop == "squiggle")
+		AddInt16Property (out, kCDXProp_Bond_Display, 8);	
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x00\x00")); // end of bond
+	return true;
+}
+
+bool CDXLoader::WriteMolecule (CDXLoader *loader, GsfOutput *out, Object *obj, GOIOContext *s)
+{
+	gint16 n = kCDXObj_Fragment;
+	WRITEINT16 (out, n);
+	loader->WriteId (obj, out);
+	// save atoms
+	std::map <std::string, Object *>::iterator i;
+	Object *child = obj->GetFirstChild (i);
+	while (child) {
+		if (child->GetType () == AtomType && !loader->WriteObject (out, child, s))
+			return false;
+		child = obj->GetNextChild (i);
+	}
+	// save fragments
+	child = obj->GetFirstChild (i);
+	while (child) {
+		if (child->GetType () == FragmentType && !loader->WriteObject (out, child, s))
+			return false;
+		child = obj->GetNextChild (i);
+	}
+	// save bonds
+	child = obj->GetFirstChild (i);
+	while (child) {
+		if (child->GetType () == BondType && !loader->WriteObject (out, child, s))
+			return false;
+		child = obj->GetNextChild (i);
+	}
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x00\x00")); // end of molecule
+	return true;
+}
+
+bool CDXLoader::WriteObject (GsfOutput *out, Object *object, GOIOContext *io)
+{
+	string name = Object::GetTypeName (object->GetType ());
+	map <string, bool (*) (CDXLoader *, GsfOutput *, Object *, GOIOContext *)>::iterator i = m_WriteCallbacks.find (name);
+	if (i != m_WriteCallbacks.end ())
+		return (*i).second (this, out, object, io);
+	// if we don't save the object iself, try tosave its children
+	std::map <std::string, Object *>::iterator j;
+	Object *child = object->GetFirstChild (j);
+	while (child) {
+		if (!WriteObject (out, child, io))
+			return false;
+		child = object->GetNextChild (j);
+	}
+	return true; /* loosing data is not considered an error, it is just a missing feature
+					either in this code or in the cml schema */
+}
+
+void CDXLoader::WriteSimpleStringProperty (GsfOutput *out, gint16 id, gint16 length, char const *data)
+{
+	WRITEINT16 (out, id);
+	gint16 l = length + 2;
+	WRITEINT16 (out, l);
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x00\x00"));
+	gsf_output_write (out, length, reinterpret_cast <guint8 const *> (data));
+}
+
+void CDXLoader::WriteId (Object *obj, GsfOutput *out)
+{
+	m_SavedIds[obj->GetId ()] = m_MaxId;
+	gint32 n = m_MaxId++;
+	WRITEINT32 (out, n);
+}
+
+void CDXLoader::AddInt16Property (GsfOutput *out, gint16 prop, gint16 value)
+{
+	WRITEINT16 (out, prop);
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x02\x00"));
+	WRITEINT16 (out, value);
+}
+
+void CDXLoader::AddInt32Property (GsfOutput *out, gint16 prop, gint32 value)
+{
+	WRITEINT16 (out, prop);
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x04\x00"));
+	WRITEINT32 (out, value);
+}
+
+bool CDXLoader::Write  (Object *obj, GsfOutput *out, G_GNUC_UNUSED G_GNUC_UNUSED char const *mime_type, GOIOContext *io, G_GNUC_UNUSED ContentType type)
+{
+	Document *doc = dynamic_cast <Document *> (obj);
+	gint16 n;
+	gint32 l;
+	if (!doc || !out)
+		return false;
+
+	m_MaxId = m_Z = 1;
+
+	// Init colors
+	m_Colors[2] = GO_COLOR_WHITE;
+	m_Colors[3] = GO_COLOR_BLACK;
+	m_Colors[4] = GO_COLOR_RED;
+	m_Colors[5] = GO_COLOR_YELLOW;
+	m_Colors[6] = GO_COLOR_GREEN;
+	m_Colors[7] = GO_COLOR_CYAN;
+	m_Colors[8] = GO_COLOR_BLUE;
+	m_Colors[9] = GO_COLOR_VIOLET;
+
+	// Init fonts, we always use Unknown as the charset, hoping it is not an issue
+	m_Fonts[3] = (CDXFont) {3, kCDXCharSetUnknown, string ("Arial")};
+	m_Fonts[4] = (CDXFont) {4, kCDXCharSetUnknown, string ("Times New Roman")};
+
 	gsf_output_write (out, kCDX_HeaderStringLen, (guint8 const *) kCDX_HeaderString);
 	gsf_output_write (out, kCDX_HeaderLength - kCDX_HeaderStringLen, (guint8 const *) "\x04\x03\x02\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x80\x00\x00\x00\x00");
+	std::string app = doc->GetApp ()->GetName () + " "VERSION;
+	WriteSimpleStringProperty (out, kCDXProp_CreationProgram, app.length (), app.c_str ());
+	// determine the bond length and scale the document appropriately
+	string prop = doc->GetProperty (GCU_PROP_THEME_BOND_LENGTH);
+	double scale = strtod (prop.c_str (), NULL);
+	doc->SetScale (scale / 1966080.);
+	n = kCDXProp_BondLength;
+	WRITEINT16 (out, n);
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x04\x00"));
+	l = 30;
+	WRITEINT32 (out, l);
 	// write the document contents
 	// there is a need for a two paths procedure
 	// in the first path, we collect fonts and colors
 	// everything else is saved during the second path
 	// write end of document and end of file
+	GsfOutput *buf = gsf_output_memory_new ();
+	n = kCDXObj_Page;
+	WRITEINT16 (buf, n);
+	l = 0;
+	WRITEINT32 (buf, l); // id = 0 for the page
+	std::map <std::string, Object *>::iterator i;
+	Object *child = doc->GetFirstChild (i);
+	while (child) {
+		if (!WriteObject (buf, child, io)) {
+			g_object_unref (buf);
+			m_Colors.clear ();
+			m_Fonts.clear ();
+			m_SavedIds.clear ();
+			return false;
+		}
+		child = doc->GetNextChild (i);
+	}
+	// write colors
+	n = kCDXProp_ColorTable;
+	WRITEINT16 (out, n);
+	n = m_Colors.size () * 6 + 2;
+	WRITEINT16 (out, n);
+	n = m_Colors.size ();
+	WRITEINT16 (out, n);
+	map <unsigned, GOColor>::iterator color, end_color = m_Colors.end ();
+	for (color = m_Colors.begin (); color != end_color; color++) {
+		n = GO_COLOR_UINT_R ((*color).second) * 0x101;
+		WRITEINT16 (out, n);
+		n = GO_COLOR_UINT_G ((*color).second) * 0x101;
+		WRITEINT16 (out, n);
+		n = GO_COLOR_UINT_B ((*color).second) * 0x101;
+		WRITEINT16 (out, n);
+	}
+
+	// write fonts
+	n = kCDXProp_FontTable;
+	WRITEINT16 (out, n);
+	n = 4;
+	map <unsigned, CDXFont>::iterator font, end_font = m_Fonts.end ();
+	for (font = m_Fonts.begin (); font != end_font; font++)
+		n += 6 + (*font).second.name.length ();
+	WRITEINT16 (out, n);
+	gsf_output_write (out, 2, reinterpret_cast <guint8 const *> ("\x00\x00")); // say we are on a mac even if not true
+	n = m_Fonts.size ();
+	WRITEINT16 (out, n);
+	for (font = m_Fonts.begin (); font != end_font; font++) {
+		WRITEINT16 (out, (*font).second.index);
+		WRITEINT16 (out, (*font).second.encoding);
+		n = (*font).second.name.length ();
+		WRITEINT16 (out, n);
+		gsf_output_write (out, n,
+		                  reinterpret_cast <guint8 const *> ((*font).second.name.c_str ()));
+	}
+
+	// write the objects
+	gint64 size;
+	g_object_get (buf, "size", &size, NULL);
+	if (size > 0)
+		gsf_output_write (out, size, gsf_output_memory_get_bytes (GSF_OUTPUT_MEMORY (buf)));
+	g_object_unref (buf);
 	gsf_output_write (out, 4, (guint8 const *) "\x00\x00\x00\x00");
+	m_Colors.clear ();
+	m_Fonts.clear ();
+	m_SavedIds.clear ();
 	return true;
 }
 
@@ -366,7 +636,7 @@ bool CDXLoader::ReadPage (GsfInput *in, Object *parent)
 bool CDXLoader::ReadMolecule (GsfInput *in, Object *parent)
 {
 	guint16 code;
-	Object *mol = Object::CreateObject ("molecule", parent);
+	Object *mol = parent->GetApplication ()->CreateObject ("molecule", parent);
 	guint32 Id;
 	if (!(READINT32 (in,Id)))
 		return false;
@@ -406,7 +676,7 @@ bool CDXLoader::ReadMolecule (GsfInput *in, Object *parent)
 bool CDXLoader::ReadAtom (GsfInput *in, Object *parent)
 {
 	guint16 code;
-	Object *Atom = Object::CreateObject ("atom", parent);
+	Object *Atom = parent->GetApplication ()->CreateObject ("atom", parent);
 	Document *Doc = NULL;
 	Atom->SetProperty (GCU_PROP_ATOM_Z, "6");
 	guint32 Id;
@@ -466,7 +736,7 @@ bool CDXLoader::ReadAtom (GsfInput *in, Object *parent)
 								if (mol)
 									mol->Remove (Atom);
 								delete Atom;
-								Atom = Object::CreateObject ("fragment", parent);
+								Atom = parent->GetApplication ()->CreateObject ("fragment", parent);
 								Atom->SetProperty (GCU_PROP_TEXT_TEXT, buf);
 								snprintf (buf, bufsize, "a%d", Id);
 								Atom->SetProperty (GCU_PROP_FRAGMENT_ATOM_ID, buf);
@@ -495,7 +765,7 @@ bool CDXLoader::ReadAtom (GsfInput *in, Object *parent)
 								if (mol)
 									mol->Remove (Atom);
 								delete Atom;
-								Atom = Object::CreateObject ("fragment", parent);
+								Atom = parent->GetApplication ()->CreateObject ("fragment", parent);
 								Atom->SetProperty (GCU_PROP_TEXT_TEXT, buf);
 								snprintf (buf, bufsize, "a%d", Id);
 								Atom->SetProperty (GCU_PROP_FRAGMENT_ATOM_ID, buf);
@@ -607,7 +877,7 @@ fragment_success:
 							if (mol)
 								mol->Remove (Atom);
 							delete Atom;
-							Atom = Object::CreateObject ("fragment", parent);
+							Atom = parent->GetApplication ()->CreateObject ("fragment", parent);
 							Atom->SetProperty (GCU_PROP_TEXT_TEXT, buf);
 							snprintf (buf, bufsize, "a%d", Id);
 							Atom->SetProperty (GCU_PROP_FRAGMENT_ATOM_ID, buf);
@@ -624,7 +894,7 @@ fragment_success:
 							if (mol)
 								mol->Remove (Atom);
 							delete Atom;
-							Atom = Object::CreateObject ("fragment", parent);
+							Atom = parent->GetApplication ()->CreateObject ("fragment", parent);
 							Atom->SetProperty (GCU_PROP_TEXT_TEXT, buf);
 							snprintf (buf, bufsize, "a%d", Id);
 							Atom->SetProperty (GCU_PROP_FRAGMENT_ATOM_ID, buf);
@@ -683,7 +953,7 @@ fragment_success:
 					if (mol)
 						mol->Remove (Atom);
 					delete Atom;
-					Atom = Object::CreateObject ("pseudo-atom", parent);
+					Atom = parent->GetApplication ()->CreateObject ("pseudo-atom", parent);
 					snprintf (buf, bufsize, "a%d", Id);
 					Atom->SetId (buf);
 					Atom->SetProperty (GCU_PROP_POS2D, pos.c_str ());
@@ -709,7 +979,7 @@ bad_exit:
 bool CDXLoader::ReadBond (GsfInput *in, Object *parent)
 {
 	guint16 code;
-	Object *Bond = Object::CreateObject ("bond", parent);
+	Object *Bond = parent->GetApplication ()->CreateObject ("bond", parent);
 	guint32 Id;
 	if (!(READINT32 (in,Id)))
 		return false;
@@ -806,7 +1076,7 @@ typedef struct {
 bool CDXLoader::ReadText (GsfInput *in, Object *parent)
 {
 	guint16 code;
-	Object *Text= Object::CreateObject ("text", parent);
+	Object *Text= parent->GetApplication ()->CreateObject ("text", parent);
 	guint32 Id;
 	guint8 TextAlign = 0xfe, TextJustify = 0xfe;
 	if (!(READINT32 (in,Id)))
@@ -889,12 +1159,12 @@ bool CDXLoader::ReadText (GsfInput *in, Object *parent)
 											str << "</i>";
 										if (attrs0.face & 1)
 											str << "</b>";
-										str << "</fore></font><font name=\"" << fonts[attrs.font].name << " " << (double) attrs.size / 30. << "\">";
+										str << "</fore></font><font name=\"" << m_Fonts[attrs.font].name << " " << (double) attrs.size / 30. << "\">";
 										str << "<fore " << colors[attrs.color] << ">";
 										str << "<sub height=\"" << (double) attrs.size / 60. << "\">";
 										while (buf[cur] >= '0' && buf[cur] <= '9'){printf("cur=%d c=%c\n",cur,buf[cur]);
 											str << buf[cur++];}
-										str << "</sub></fore></font><font name=\"" << fonts[attrs.font].name << " " << (double) attrs.size / 20. << "\">";
+										str << "</sub></fore></font><font name=\"" << m_Fonts[attrs.font].name << " " << (double) attrs.size / 20. << "\">";
 										str << "<fore " << colors[attrs.color] << ">";
 										if (attrs0.face & 1)
 											str << "<b>";
@@ -924,7 +1194,7 @@ bool CDXLoader::ReadText (GsfInput *in, Object *parent)
 						}
 						if ((attrs.face & 0x60) != 0 && (attrs.face & 0x60) != 0x60)
 							attrs.size = attrs.size * 2 / 3;
-						str << "<font name=\"" << fonts[attrs.font].name << " " << (double) attrs.size / 20. << "\">";
+						str << "<font name=\"" << m_Fonts[attrs.font].name << " " << (double) attrs.size / 20. << "\">";
 						str << "<fore " << colors[attrs.color] << ">";
 						if (attrs.face & 1)
 							str << "<b>";
@@ -961,14 +1231,14 @@ bool CDXLoader::ReadText (GsfInput *in, Object *parent)
 									str << "</i>";
 								if (attrs0.face & 1)
 									str << "</b>";
-								str << "</fore></font><font name=\"" << fonts[attrs.font].name << " " << (double) attrs.size / 30. << "\">";
+								str << "</fore></font><font name=\"" << m_Fonts[attrs.font].name << " " << (double) attrs.size / 30. << "\">";
 								str << "<fore " << colors[attrs.color] << ">";
 								str << "<sub height=\"" << (double) attrs.size / 60. << "\">";
 								while (buf[cur] >= '0' && buf[cur] <= '9')
 									str << buf[cur++];
 								str << "</sub></fore></font>";
 								if (cur < size) {
-									str << "<font name=\"" << fonts[attrs.font].name << " " << (double) attrs.size / 20. << "\">";
+									str << "<font name=\"" << m_Fonts[attrs.font].name << " " << (double) attrs.size / 20. << "\">";
 									str << "<fore " << colors[attrs.color] << ">";
 									if (attrs0.face & 1)
 										str << "<b>";
@@ -1060,7 +1330,7 @@ bool CDXLoader::ReadText (GsfInput *in, Object *parent)
 bool CDXLoader::ReadGroup (GsfInput *in, Object *parent)
 {
 	guint16 code;
-	Object *Group= Object::CreateObject ("group", parent);
+	Object *Group= parent->GetApplication ()->CreateObject ("group", parent);
 	Group->Lock ();
 	if (gsf_input_seek (in, 4, G_SEEK_CUR)) //skip the id
 		return false;
@@ -1137,20 +1407,20 @@ bool CDXLoader::ReadGraphic  (GsfInput *in, Object *parent)
 		switch (arrow_type) {
 		case 1:
 		case 2:
-			obj = Object::CreateObject ("reaction-arrow", parent);
+			obj = parent->GetApplication ()->CreateObject ("reaction-arrow", parent);
 			snprintf (buf, bufsize, "ra%d", Id);
 			break;
 		case 4:
-			obj = Object::CreateObject ("mesomery-arrow", parent);
+			obj = parent->GetApplication ()->CreateObject ("mesomery-arrow", parent);
 			snprintf (buf, bufsize, "ma%d", Id);
 			break;
 		case 8:
-			obj = Object::CreateObject ("reaction-arrow", parent);
+			obj = parent->GetApplication ()->CreateObject ("reaction-arrow", parent);
 			snprintf (buf, bufsize, "ra%d", Id);
 			obj->SetProperty (GCU_PROP_REACTION_ARROW_TYPE, "double");
 			break;
 		case 32:
-			obj = Object::CreateObject ("retrosynthesis-arrow", parent);
+			obj = parent->GetApplication ()->CreateObject ("retrosynthesis-arrow", parent);
 			snprintf (buf, bufsize, "rsa%d", Id);
 			break;
 		default:
