@@ -23,6 +23,7 @@
  */
 
 #include "config.h"
+#include <gcu/application.h>
 #include <gcu/document.h>
 #include <gcu/loader.h>
 #include <gcu/element.h>
@@ -70,7 +71,7 @@ CIFLoader::CIFLoader ()
 	KnownProps["_cell_length_a"] = GCU_PROP_CELL_A;
 	KnownProps["_cell_length_b"] = GCU_PROP_CELL_B;
 	KnownProps["_cell_length_c"] = GCU_PROP_CELL_C;
-	KnownProps["_cell_angle_alpha"] = GCU_PROP_CELL_ALPHA;
+	KnownProps["_cell_angle_apha"] = GCU_PROP_CELL_ALPHA;
 	KnownProps["_cell_angle_beta"] = GCU_PROP_CELL_BETA;
 	KnownProps["_cell_angle_gamma"] = GCU_PROP_CELL_GAMMA;
 
@@ -112,9 +113,10 @@ typedef struct {
 ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char const *mime_type, G_GNUC_UNUSED GOIOContext *io)
 {
 	ContentType type = ContentTypeCrystal;
+	Application *app = doc->GetApplication ();
 	GsfInputTextline *input = reinterpret_cast <GsfInputTextline *> (gsf_input_textline_new (in));
 	char *buf;
-	bool in_string = false, in_loop = false, waiting_value = false, empty = true;
+	bool in_string = false, in_loop = false, waiting_value = false;
 	string key, value;
 	int size;
 	char endstr = 0;
@@ -134,7 +136,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 		size = strlen (buf);
 		// check for new data bloc
 		if (!strncmp (cur, "data_", 5)) {
-			if (!empty)
+			if (!doc->GetEmpty ())
 				// FIXME: implement multiple data blocs reading
 				goto read_exit;
 		}
@@ -262,7 +264,7 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 							case LOOP_ATOM: {
 								double scale = doc->GetScale ();
 								doc->SetScale (1.);
-								Object *atom = Object::CreateObject ("atom", NULL);
+								Object *atom = app->CreateObject ("atom", NULL);
 								for (loop_prop = loop_contents.begin (); loop_prop != loop_contents.end (); loop_prop++) {
 									std::string val = loop_values.front ();
 									loop_values.pop_front ();
@@ -275,7 +277,6 @@ ContentType CIFLoader::Read  (Document *doc, GsfInput *in, G_GNUC_UNUSED char co
 										} else {
 											LabeledAtoms[val] = atom;
 											doc->AddChild (atom);
-											empty = false;
 										}
 										if (AtomTypes.empty ()) {
 											int i = 0;
