@@ -2,7 +2,7 @@
  * GChemPaint selection plugin
  * group.cc
  *
- * Copyright (C) 2004-2008 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2004-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -111,10 +111,10 @@ void gcpGroup::Align ()
 {
 	if (!m_Align)
 		return;
-/*	map<Object*, double> Children;
+	map<Object*, double> Children;
 	map<string, Object*>::iterator i;
 	Object* obj = GetFirstChild (i);
-	ArtDRect rect;
+	gccv::Rect rect;
 	gcp::Document *pDoc = dynamic_cast <gcp::Document*> (GetDocument ());
 	gcp::View *View = pDoc->GetView ();
 	gcp::Theme *pTheme = pDoc->GetTheme ();
@@ -180,19 +180,19 @@ void gcpGroup::Align ()
 		View->Update (obj);
 		obj = GetNextChild (i);
 	}
-	Space ();*/
+	Space ();
 }
 
 void gcpGroup::Space ()
 {
 	if (!m_Align || !m_Spaced)
 		return;
-/*	map<string, Object*>::iterator i;
-	map<Object*, ArtDRect> rects;
+	map<string, Object*>::iterator i;
+	map<Object*, gccv::Rect> rects;
 	map<double, Object*> Children;
 	map<double, Object*>::iterator im, endm;
 	Object* obj = GetFirstChild (i);
-	ArtDRect rect;
+	gccv::Rect rect;
 	double x;
 	gcp::Document *pDoc = dynamic_cast <gcp::Document*> (GetDocument ());
 	gcp::View *View = pDoc->GetView ();
@@ -224,7 +224,7 @@ void gcpGroup::Space ()
 			x += (rect.y1 - rect.y0) /pTheme->GetZoomFactor ();
 		}
 		View->Update (obj);
-	}*/
+	}
 }
 
 bool gcpGroup::Load (xmlNodePtr node)
@@ -269,12 +269,11 @@ bool gcpGroup::Load (xmlNodePtr node)
 				xmlFree (buf);
 			}
 			((gcp::Document*) GetDocument ())->GetView ()->AddObject (this);
-/*			gcp::WidgetData  *pData= (gcp::WidgetData*) g_object_get_data (G_OBJECT (((gcp::Document*) GetDocument ())->GetWidget ()), "data");
-			gnome_canvas_update_now (GNOME_CANVAS (pData->Canvas));*/
 			Align ();
 		}
 	}
 	Lock (false);
+	GetDocument ()->ObjectLoaded (this);
 	return true;
 }
 
@@ -316,25 +315,20 @@ xmlNodePtr gcpGroup::Save (xmlDocPtr xml) const
 	return node;
 }
 
-bool gcpGroup::OnSignal (SignalId Signal, Object *Child)
+bool gcpGroup::OnSignal (SignalId Signal, G_GNUC_UNUSED Object *Child)
 {
 	if (IsLocked ())
 		return false;
 	if (Signal == gcp::OnChangedSignal) {
 		if (GetChildrenNumber () < 2)
 			delete this;
-		else {
-/*			GnomeCanvas* w = GNOME_CANVAS (((gcp::Document*) GetDocument ())->GetWidget ());
-			while (w->idle_id)
-				gtk_main_iteration();
-			gnome_canvas_update_now (w);*/
+		else
 			Align ();
-		}
 	}
 	return true;
 }
 
-void gcpGroup::Transform2D (Matrix2D& m, double x, double y)
+void gcpGroup::Transform2D (G_GNUC_UNUSED Matrix2D& m, G_GNUC_UNUSED double x, G_GNUC_UNUSED double y)
 {
 }
 
@@ -347,17 +341,6 @@ double gcpGroup::GetYAlign ()
 	return (rect.y1 - rect.y0) / 2.;
 }
 
-void gcpGroup::Add (GtkWidget* w)
-{
-	map<string, Object*>::iterator i;
-	Object* p = GetFirstChild (i);
-	while (p)
-	{
-//		p->Add (w);
-		p = GetNextChild (i);
-	}
-}
-
 void gcpGroup::OnLoaded ()
 {
 	if (GetChildrenNumber () < 2)
@@ -365,3 +348,8 @@ void gcpGroup::OnLoaded ()
 	else
 		Align ();
 }
+
+std::string gcpGroup::Name ()
+{
+	return _("Group");
+}
