@@ -4,7 +4,7 @@
  * Gnome Crystal
  * cleavagesdlg.cc 
  *
- * Copyright (C) 2002-2011 Jean Bréfort <jean.brefort@normalesup.org>
+ * Copyright (C) 2002-2010 Jean Bréfort <jean.brefort@normalesup.org>
  *
  * This program is free software; you can redistribute it and/or 
  * modify it under the terms of the GNU General Public License as 
@@ -79,7 +79,6 @@ gcCleavagesDlg::gcCleavagesDlg (gcApplication *App, gcDocument* pDoc): Dialog (A
 	DeleteAllBtn = GetWidget ("delete_all");
 	g_signal_connect (G_OBJECT (DeleteAllBtn), "clicked", G_CALLBACK (on_delete_all), this);
 	FixedBtn = GTK_TOGGLE_BUTTON (GetWidget ("fixed"));
-	gtk_toggle_button_set_active (FixedBtn, m_pDoc->GetFixedSize ());
 	GtkTreeView* tree = GTK_TREE_VIEW (GetWidget ("cleavageslist"));
 	Selection = gtk_tree_view_get_selection (tree);
 	CleavageList = gtk_list_store_new (5, G_TYPE_INT, G_TYPE_INT, G_TYPE_INT, G_TYPE_UINT, G_TYPE_BOOLEAN);
@@ -127,11 +126,11 @@ gcCleavagesDlg::gcCleavagesDlg (gcApplication *App, gcDocument* pDoc): Dialog (A
 	gtk_tree_view_column_set_fixed_width (GTK_TREE_VIEW_COLUMN (column), 75);
 	gtk_tree_view_append_column (tree, column);
 	m_Cleavages = g_array_sized_new (FALSE, FALSE, sizeof (struct CleavageStruct), 1);
-	CrystalCleavageList* Cleavages = m_pDoc->GetCleavageList ();
-	CrystalCleavage* pCleavage;
+	gcr::CleavageList* Cleavages = m_pDoc->GetCleavageList ();
+	gcr::Cleavage* pCleavage;
 	struct CleavageStruct s;
 	GtkTreeIter iter;
-	for (list<CrystalCleavage*>::iterator i = Cleavages->begin (); i != Cleavages->end (); i++)
+	for (list<gcr::Cleavage*>::iterator i = Cleavages->begin (); i != Cleavages->end (); i++)
 	{
 		pCleavage = *i;
 		s.h = pCleavage->h ();
@@ -160,7 +159,7 @@ gcCleavagesDlg::~gcCleavagesDlg()
 
 bool gcCleavagesDlg::Apply()
 {
-	CrystalCleavageList* Cleavages = m_pDoc->GetCleavageList();
+	gcr::CleavageList* Cleavages = m_pDoc->GetCleavageList();
 	//First, delete old Cleavages
 	while (!Cleavages->empty())
 	{
@@ -169,13 +168,13 @@ bool gcCleavagesDlg::Apply()
 	}
 	//Add new Cleavages from array
 	
-	CrystalCleavage* c;
+	gcr::Cleavage* c;
 	struct CleavageStruct* s;
 	for (unsigned i = 0; i  < m_Cleavages->len; i++)
 	{
 		s = &g_array_index(m_Cleavages, struct CleavageStruct, i);
 		if (!s->planes || ((!s->h) && (!s->k) && (!s->l))) continue;
-		c = new CrystalCleavage();
+		c = new gcr::Cleavage();
 		c->h() = s->h;
 		c->k() = s->k;
 		c->l() = s->l;
